/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997, 1998, 1999  Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
*/

#include "SDL_direct3dcommon.h"
#include "SDL_direct3dtexturegrid.h"
#include "SDL_direct3dvideo.h"

extern SDLD3D_ScreenFlags g_ScreenFlags;
extern HINSTANCE Direct3D_DLL;


SDLD3D_ScreenFlags SDLD3D_GetScreenFlags()
{
	return g_ScreenFlags;
}

void SDLD3D_SetScreenFlags(SDLD3D_ScreenFlags flags)
{
	g_ScreenFlags = flags;
}

int SDLD3D_GetBlendMode(SDL_Surface *surface, SDLD3D_BlendMode *output_blend_mode)
{
	if ( (surface->flags & SDL_HWSURFACE) != SDL_HWSURFACE ) {
		SDL_SetError("SDLD3D_GetBlendMode cannot be called on a non-HW surface.");
		return -1;
	}

	if ( output_blend_mode ) {
		*output_blend_mode = surface->hwdata->blend_mode;
	}

	return 0;
}

int SDLD3D_SetBlendMode(SDL_Surface *surface, SDLD3D_BlendMode blend_mode)
{
	if ( (surface->flags & SDL_HWSURFACE) != SDL_HWSURFACE ) {
		SDL_SetError("SDLD3D_SetBlendMode cannot be called on a non-HW surface.");
		return -1;
	}

	surface->hwdata->blend_mode = blend_mode;
	return 0;
}

static int IsDirect3DDriverActive()
{
	if (Direct3D_DLL == NULL ||
		current_video == NULL ||
		current_video->hidden == NULL ||
		current_video->hidden->__d3d9_device == NULL)
	{
		/* it's not available */
		return 0;
	}
	else
	{
		/* it is available */
		return 1;
	}
}

/*
void SDLD3D_GetDirect3DDevice(void **output_device_pointer)
{
	if (output_device_pointer == NULL)
	{
		SDL_SetError("SDLD3D_GetDirect3DDevice cannot be passed a NULL pointer.");
		return;
	}

	if (Direct3D_DLL == NULL ||
		current_video == NULL ||
		current_video->hidden == NULL ||
		current_video->hidden->__d3d9_device == NULL)
	{
		*output_device_pointer = NULL;
		SDL_SetError("SDL's Direct3D driver is not active.");
		return;
	}

	*output_device_pointer = current_video->hidden->__d3d9_device;
}
/**/

int SDLD3D_GetSurfaceMemoryUsage(SDL_Surface *surface)
{
	int estimatedMemoryUsage = 0;

	if ( IsDirect3DDriverActive() == 0 ) {
		SDL_SetError("SDL's Direct3D driver is not active.");
		return 0;
	}

	if ( (surface->flags & SDL_HWSURFACE) != SDL_HWSURFACE ) {
		SDL_SetError("SDLD3D_GetSurfaceMemoryUsage cannot be called on a non-HW surface.");
		return 0;
	}

	if ( surface->hwdata == NULL || surface->hwdata->texture_grid == NULL ) {
		SDL_SetError("SDLD3D_GetSurfaceMemoryUsage encountered an unknown error.");
		return 0;
	}

	estimatedMemoryUsage = surface->format->BytesPerPixel *
		surface->hwdata->texture_grid->texture_width *
		surface->hwdata->texture_grid->texture_height *
		surface->hwdata->texture_grid->columns *
		surface->hwdata->texture_grid->rows;

	return estimatedMemoryUsage;
}

