/*
    SDL - Simple DirectMedia Layer
    Copyright (C) 1997-2004 Sam Lantinga

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; if not, write to the Free
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Sam Lantinga
    slouken@libsdl.org
*/

#ifndef _SDL_direct3dtexturegrid_h
#define _SDL_direct3dtexturegrid_h

#include "SDL_direct3dcommon.h"
#include "SDL_direct3dvideo.h"

/* TextureGrid represents a two-dimensional grid of textures.  Each cell
   consists of a single Direct3D texture, and typically has dimensions in
   powers of two.  This is a requirement imposed by most video cards.

   NOTE: All textures in a particular grid share the same size, however any row
   or column may have a different "real" size, which indicates where the edge
   of the actual image is.
*/
struct TextureGrid {
	/* Number of cells */
	int columns, rows;

	/* Texture size */
	int texture_width, texture_height;

	/* Column and row sizes */
	int *cell_widths;
	int *cell_heights;

	/* Texture data */
	IDirect3DTexture9 ***textures;
};


/* Create a TextureGrid */
HRESULT TextureGrid_create(_THIS,
						   int imageWidth, int imageHeight,
						   int maxCellWidth, int maxCellHeight,
						   struct TextureGrid **output);

/* Destroy a texture grid, along with all of its textures */
void TextureGrid_destroy(struct TextureGrid *grid);

/* Copy pixel data to a texture grid */
HRESULT TextureGrid_copyPixelsFromSurface(struct TextureGrid *grid,
										  SDL_Surface *srcData);

/* Draw a texture grid to the screen */
HRESULT TextureGrid_draw(struct TextureGrid *grid,
						 IDirect3DDevice9 *device,
						 SDL_Rect *src_rect,
						 SDL_Rect *dst_rect,
						 Uint8 src_surface_alpha);

#endif
